[−][src]Crate imgui_inspect
Re-exports
pub use super::*; |
pub use super::*; |
Structs
| InspectArgsDefault | Options for using the default rendering style for the element. The options here are a superset of all other options since "default" could be any of the widgets |
| InspectArgsSlider | Options for rendering a values as a slider. |
| InspectArgsStruct | Options for rendering a value as a struct (i.e. draw all of its subfields) |
Traits
| InspectRenderDefault | Renders a value using the default widget |
| InspectRenderSlider | Renders a value as a slider |
| InspectRenderStruct | Renders a struct (i.e. draw all of its subfields). Most traits are implemented by hand-written code, but this trait
is normally generated by putting |
Functions
| get_same_or_none | Utility function that, given a list of references, returns Some(T) if they are the same, otherwise None |