[][src]Struct imgui_inspect::InspectArgsDefault

pub struct InspectArgsDefault {
    pub header: Option<bool>,
    pub indent_children: Option<bool>,
    pub min_value: Option<f32>,
    pub max_value: Option<f32>,
    pub step: Option<f32>,
}

Options for using the default rendering style for the element. The options here are a superset of all other options since "default" could be any of the widgets

Fields

header: Option<bool>indent_children: Option<bool>min_value: Option<f32>max_value: Option<f32>step: Option<f32>